==> haskell-http2-1.6.3-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-8dSgU560mwzKad6a6X7WC0
key: http2-1.6.3-8dSgU560mwzKad6a6X7WC0
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
abi: 6f7a9d7294b360fa5cba8ff44de5581e
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/http2-1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http2-1.6.3
hs-libraries: HShttp2-1.6.3-8dSgU560mwzKad6a6X7WC0
depends:
    base-4.11.1.0 array-0.5.2.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 psqueues-0.2.7.0-E03lseHbANt3EeSAMky6qt
    stm-2.4.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             psqueues-0.2.7.0-E03lseHbANt3EeSAMky6qt=9a4c4755c86eb5578bebd2f64edf0eb8
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.6.3-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-CzMMEHPfWN9IL57FYTRPgr
key: http2-1.6.3-CzMMEHPfWN9IL57FYTRPgr
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
abi: 259f6f207ef633e5944bb581bd2f9665
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/http2-1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http2-1.6.3
hs-libraries: HShttp2-1.6.3-CzMMEHPfWN9IL57FYTRPgr
depends:
    base-4.11.1.0 array-0.5.2.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 psqueues-0.2.7.0-C8U6wpSa9CvPbLQw7K0vW
    stm-2.4.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             psqueues-0.2.7.0-C8U6wpSa9CvPbLQw7K0vW=4d6f12ed22d021a6b5d8c0d1d925c472
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
